Exception: Lemans::VerifierError

Inherits:
InfrastructureError show all
Defined in:
lib/lemans.rb

Overview

The verifier itself failed, or wrote something that is not a reward. Retrying would verify the same patch the same way, so it is terminal.